@@ -99,8 +99,12 @@ class VariableOsAudioData(ReadonlyTableVariable):
                          for x in readLinesFile(playback_info))
                 dInfo = {x.strip(): y.strip() for x, y in dInfo}
                 if all(x in dInfo for x in ('card', 'device', 'name')):
-                    yield ("%s,%s" % (dInfo['card'], dInfo['device']),
-                           "%s, %s" % (card_name, dInfo['name']))
+                    if card_name == dInfo['name']:
+                        yield ("%s,%s" % (dInfo['card'], dInfo['device']),
+                               "%s" % card_name)
+                    else:
+                        yield ("%s,%s" % (dInfo['card'], dInfo['device']),
+                               "%s, %s" % (card_name, dInfo['name']))
 
     def get(self, hr=HumanReadable.No):
         # /proc/asound/card*/pcm*p/info
